library(tidyverse)
library(weights)
library(ggpubr)
library(cowplot)
library(data.table)
library(foreign)
library(MASS)
library(sfsmisc)

#The raw data for the following objects have to be obtained via agreements with various institutions
EGFRm_phe_plot_df
taiwan_df
korea_df 
  

EGFRm_phe_plot = EGFRm_phe_plot_df %>%
  mutate(YEAR=factor(YEAR)) %>%
  ggplot(aes(x=mean_poll,y=EGFRm_Point_Estimate)) +
  geom_point(aes(size=total_tested)) +
  theme_cowplot() +
  geom_smooth(method = MASS::rlm, se = TRUE,color="blue") +
  ylab("EGFRm LC Incidence") +
  xlab("Mean PM2.5")+
  ggtitle("England") +
  ylim(0,35)+
  scale_size(range = c(1, 5),
             limits=c(1,1500),
             breaks = c(1,500,1000,1500))

lm_res = lm(EGFRm_phe_plot_df$EGFRm_Point_Estimate~EGFRm_phe_plot_df$mean_poll)
summary(lm_res)

rlm_res = rlm(EGFRm_phe_plot_df$EGFRm_Point_Estimate~EGFRm_phe_plot_df$mean_poll)
f.robftest(rlm_res)

wtd.cor(phe_df$EGFRm_Point_Estimate,phe_df$mean_poll,
        phe_df$total_tested)

var_oi = "EGFRm"
EGFRm_taiwan_plot_df = taiwan_df %>%
  filter(variable==var_oi,testing_no>=10) 

EGFRm_taiwan_plot = EGFRm_taiwan_plot_df %>%
  mutate(year=factor(year)) %>%
  ggplot(aes(x=pm2_5_2,y=var_incidence_100_000)) +
  geom_point(aes(size=testing_no)) +
  theme_cowplot() +
  geom_smooth(method = MASS::rlm, se = TRUE,color="blue") +
  ylab("EGFRm LC Incidence") +
  xlab("Mean PM2.5")+
  ggtitle("Taiwan")+
  scale_size(range = c(1, 5),
             limits=c(1,1500),
             breaks = c(1,500,1000,1500))

lm_res = lm(EGFRm_taiwan_plot_df$var_incidence_100_000~EGFRm_taiwan_plot_df$pm2_5_2)
summary(lm_res)

rlm_res = rlm(EGFRm_taiwan_plot_df$var_incidence_100_000~EGFRm_taiwan_plot_df$pm2_5_2)
f.robftest(rlm_res)

wtd.cor(EGFRm_taiwan_plot_df$var_incidence_100_000,EGFRm_taiwan_plot_df$pm2_5_2,
        EGFRm_taiwan_plot_df$testing_no)

EGFRm_korea_plot_df = korea_df %>%
  mutate(Year=factor(Year)) %>%
  mutate(EGFRm_LC_Incidence=EGFR_freq*incidence)
  
EGFRm_korea_plot = EGFRm_korea_plot_df %>%
  ggplot(aes(x=PM2.5,y=EGFRm_LC_Incidence)) +
  geom_point(aes(size=Total)) +
  theme_cowplot() +
  geom_smooth(method = MASS::rlm, se = TRUE,color="blue") +
  ylab("EGFRm LC Incidence") +
  xlab("Mean PM2.5")+
  ggtitle("Korea") +
  ylim(0,35)+
  scale_size(range = c(1, 5),
             limits=c(1,1500),
             breaks = c(1,500,1000,1500))

lm_res = lm(EGFRm_korea_plot_df$EGFRm_LC_Incidence~EGFRm_korea_plot_df$PM2.5)
summary(lm_res)

rlm_res = rlm(EGFRm_korea_plot_df$EGFRm_LC_Incidence~EGFRm_korea_plot_df$PM2.5)
f.robftest(rlm_res)

wtd.cor(EGFRm_korea_plot_df$EGFRm_LC_Incidence,EGFRm_korea_plot_df$`PM2.5`,
        EGFRm_korea_plot_df$Total)


EGFRm_plots = plot_grid(EGFRm_phe_plot,EGFRm_korea_plot,EGFRm_taiwan_plot,ncol=3,align="v")
