library(ggpubr)
library(data.table)
library(ggplot2)
library(janitor)
library(dplyr)
library(cowplot)
library(tidyr)
library(patchwork)

duplex_anno_df = fread("DATA/PEACE_BDRE_duplex_anno_df.txt")

strong_driver = c("L858R","G719S","L861Q","S768I","G719S","G719C","G719D","G719A","T725M","V689M","E709K","E709Q","S720P","A839T","L861R","G719A","R776H","Exon19Del","V765M",
									                  "G13D","G13V","G13C","G12D","G12C","Q61H","G12S","G12V","G12A","G12R","Q61R","Q61L","Q61*","Q61K")

mut_count_df = duplex_anno_df %>%
  mutate(smoking_status=ifelse(smoking_status=="","Unknown",smoking_status)) %>%
  group_by(cohort,sample,smoking_status,age,sex) %>%
  tally()

cos_mut_count_df = duplex_anno_df %>%
  filter(!is.na(cosmic70)|mutation_aa%in%strong_driver) %>%
  mutate(smoking_status=ifelse(smoking_status=="","Unknown",smoking_status)) %>%
  group_by(cohort,sample,smoking_status,age,sex) %>%
  tally()

cosmic_mut_plot = cos_mut_count_df %>%
  filter(smoking_status=="Never Smoked") %>%
  filter(cohort=="PEACE") %>%
  ggplot(aes(x=age,y=n)) +
  geom_point(size=3) +
  stat_cor(method = "spearman")  +
  geom_smooth(method = "lm", se = FALSE) +
  facet_wrap(~cohort+smoking_status,scales="free") +
  theme_cowplot() +
  ylab("Mutation Count") +
  xlab("Age") +
  ggtitle("Driver Mutations Identified Using Duplex-seq")

