library(data.table)
library(ggplot2)
library(janitor)
library(dplyr)
library(cowplot)
library(ggpubr)
library(tidyr)

duplex_anno_df = fread("DATA/PEACE_BDRE_duplex_anno_df.txt")

#EGFR/KRAS VAFs - Smoking Status
af_summary_plot = duplex_anno_df %>%
  filter(HICNT>=2) %>%
  filter(!is.na(cosmic70)) %>%
  filter(cohort=="PEACE") %>%
  filter(SYMBOL%in%c("EGFR","KRAS")) %>%
  filter(Consequence=="missense_variant") %>%
  filter(smoking_status!="") %>%
  ggplot(aes(x=SYMBOL,y=log10(AF_to_plot))) +
  geom_boxplot() +
  stat_compare_means(method="wilcox") +
  ggtitle("All Cases")+
  ylim(-4,-2) +
  ylab("EGFRm / KRASm log10(VAF)") +
  facet_wrap(~smoking_status)


sample_order = duplex_anno_df %>%
  filter(!is.na(cosmic70)) %>%
  filter(SYMBOL%in%c("EGFR","KRAS")) %>%
  arrange(-AF_to_plot) %>% 
  pull(sample) %>%
  unique()

smoker_individual_sample_plot = duplex_anno_df %>%
  filter(HICNT>=2) %>%
  filter(!is.na(cosmic70)) %>%
  filter(cohort=="PEACE") %>%
  filter(SYMBOL%in%c("EGFR","KRAS")) %>%
  filter(smoking_status=="Ever Smoked") %>%
  filter(Consequence=="missense_variant") %>%
  filter(smoking_status!="") %>%
  mutate(sample=factor(sample,levels=sample_order)) %>%
  ggplot(aes(x=sample,y=log10(AF_to_plot))) +
  geom_point(aes(color=SYMBOL)) +
  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1)) +
  ggtitle("Ever Smoked") +
  ylim(-4,-2)+
  ylab("EGFRm / KRASm log10(VAF)")


n_smoker_individual_sample_plot = duplex_anno_df %>%
  filter(HICNT>=2) %>%
  filter(!is.na(cosmic70)) %>%
  filter(cohort=="PEACE") %>%
  filter(SYMBOL%in%c("EGFR","KRAS")) %>%
  filter(smoking_status=="Never Smoked") %>%
  filter(Consequence=="missense_variant") %>%
  filter(smoking_status!="") %>%
  mutate(sample=factor(sample,levels=sample_order)) %>%
  ggplot(aes(x=sample,y=log10(AF_to_plot))) +
  geom_point(aes(color=SYMBOL)) +
  theme(axis.text.x = element_text(angle = 90, vjust = 0.5, hjust=1)) +
  ggtitle("Never Smoked")+
  ylim(-4,-2)+
  ylab("EGFRm / KRASm log10(VAF)")


# VAFs of high-confidence KRAS mutations were consistently higher than those in EGFR in the four ever-smoker cases that harboured oncogenic mutations in both genes 
KRAS_VAFs = duplex_anno_df %>%
  filter(HICNT>=2) %>%
  filter(!is.na(cosmic70)) %>%
  filter(cohort=="PEACE") %>%
  filter(SYMBOL%in%c("EGFR","KRAS")) %>%
  filter(smoking_status=="Ever Smoked") %>%
  filter(Consequence=="missense_variant") %>%
  filter(smoking_status!="") %>%
  mutate(sample=factor(sample,levels=sample_order)) %>%
  filter(sample%in%c("CRUKP3069","CRUKP3201","CRUKP9911","CRUKP2907")) %>%
  arrange(sample) %>%
  filter(SYMBOL=="KRAS") %>%
  pull(AF_to_plot)

EGFR_VAFs = duplex_anno_df %>%
  filter(HICNT>=2) %>%
  filter(!is.na(cosmic70)) %>%
  filter(cohort=="PEACE") %>%
  filter(SYMBOL%in%c("EGFR","KRAS")) %>%
  filter(smoking_status=="Ever Smoked") %>%
  filter(Consequence=="missense_variant") %>%
  filter(smoking_status!="") %>%
  mutate(sample=factor(sample,levels=sample_order)) %>%
  filter(sample%in%c("CRUKP3069","CRUKP3201","CRUKP9911","CRUKP2907")) %>%
  arrange(sample) %>%
  filter(SYMBOL=="EGFR") %>%
  pull(AF_to_plot)

t.test((KRAS_VAFs),(EGFR_VAFs),paired = TRUE)
