################
# Forest plots #
################
library(ggplot2)
library(readxl)

## Results for time at baseline address >=3 years prior to baseline 
cancer_pm2.5 = as.data.frame(read_excel("C:/Users/Marce/Documents/MBPhD/LCINS/codeRunThrough/Supplementary Table S4 - UK Biobank Interaction Tests & Cancer Type Definitions.xlsx", sheet = "Lung (migration)"))

cancer_pm2.5 = cancer_pm2.5[cancer_pm2.5$Variable %in% c("Previous smoker", "Current smoker", "Age", "PM2.5", "Pack-years of smoking", 
                                                         "Passive smoking", "BMI", "Male sex", "Educational attainment (Degree/Professional qualification)",
                                                         "Household income (>= £31,000)"), ]



# if p value is less than 0.001, replace with p<0.001
cancer_pm2.5$Significance = NA
cancer_pm2.5[cancer_pm2.5$pval == "<0.001", "Significance"] = "p<0.05"
cancer_pm2.5[cancer_pm2.5$pval == "0.743", "Significance"] = "ns"
cancer_pm2.5[cancer_pm2.5$pval == "0.044", "Significance"] = "p<0.05"


## clean coefficient names
cancer_pm2.5[cancer_pm2.5$Variable == "Educational attainment (Degree/Professional qualification)", "Variable"] = "Education (Degree/Professional)"
cancer_pm2.5[cancer_pm2.5$Variable == "Pack-years of smoking", "Variable"] = "Pack-years"
cancer_pm2.5[cancer_pm2.5$Variable == "Household income (>= £31,000)", "Variable"] = "Household income (>=£31k)"

cancer_pm2.5$Variable = factor(cancer_pm2.5$Variable,
                                  levels = cancer_pm2.5[order(cancer_pm2.5$HR, decreasing = F), "Variable"])

cancer_pm2.5$logHR = log2(cancer_pm2.5$HR)
cancer_pm2.5$logLowerCI = log2(cancer_pm2.5$LowerCI)
cancer_pm2.5$logUpperCI = log2(cancer_pm2.5$UpperCI)

### forest plot with log x-scale
ggplot(data = cancer_pm2.5) +
  geom_point(mapping = aes(x = logHR, y = Variable, group = Significance, color = Significance), size = 4, shape = 19) +
  geom_errorbarh(aes(xmin = logLowerCI, xmax = logUpperCI, y = Variable), height = 0.2, size = 0.5) +
  geom_vline(xintercept = 0, linetype = "dashed") +
  ggtitle("UK Biobank: Lung Cancer Incidence", subtitle = "371,543 Participants who have lived at the\nsame location for 3 years prior to registration") +
  annotate(geom = "text", x = rep(3.6, length(cancer_pm2.5$Variable)), 
           y = cancer_pm2.5$Variable, label = cancer_pm2.5$pval) +
  coord_cartesian(xlim = c(-1, 2.8), clip = "off") +
  xlab("log2 Hazard ratio (95% CI)") + ylab("Variables\n") +
  theme(axis.title.x = element_text(size = 16, vjust = 0, face = "bold"),
        axis.text = element_text(size = 14), axis.title.y = element_text(size = 16, face = "bold"),
        axis.line = element_line(color = "black"), panel.background = element_rect(fill = "white"),
        plot.margin = unit(c(1,6,1,1), "lines"), title = element_text(face = "bold", size = 14),
        legend.text = element_text(size = 14), legend.title = element_text(size = 14),
        legend.position = "bottom", plot.title = element_text(hjust = 0.5), plot.subtitle = element_text(hjust = 0.5, face = "plain")) 
dev.off()
