# Load libraries
library(readxl)
library(dplyr)
library(ggplot2)
library(ggrepel)
library(RColorBrewer)
library(cowplot)
"%ni%" <- Negate("%in%")

# Read in Supplementary Table S5 - Mouse and Human DGE Analysis Comparison
plot_df = read_excel(path = "/Path/To/Supplementary Table S5.xlsx", sheet = "Mouse and Human DGE Analysis Co") 
                       
# Plot human and mouse genes comparison
ggplot(plot_df) +
  geom_rect(data = plot_df[1,], aes(ymin = -Inf, ymax = 0, xmin = -Inf, xmax = 0), fill = "navy", alpha = 0.5) +
  geom_rect(data = plot_df[1,], aes(ymin = 0, ymax = Inf, xmin = 0, xmax = Inf), fill = "firebrick", alpha = 0.5) +
  geom_point(aes(human_log2fc, mouse_log2fc), alpha = 0.9, size = 2, colour = "#bababa") +
  geom_point(data = plot_df %>% filter(gene_categ %ni% c(NA, "NA")), 
             aes(x = human_log2fc, y = mouse_log2fc, 
                 colour = gene_categ, shape = label_shape), size = 3) +
  scale_shape_manual(name = "LogFC Concordance (Species enrichment)", values = c(15, 19)) +
  scale_colour_brewer(name = "Function of\ngenes of interest", palette = "Dark2") +
  geom_hline(yintercept = 0, linetype = "dashed") +
  geom_vline(xintercept = 0, linetype = "dashed") +
  geom_label_repel(data = plot_df %>% filter(gene_categ %ni% c(NA, "NA")),
                   mapping = aes(label = geneSymbol_label, x = human_log2fc, y = mouse_log2fc),
                   max.overlaps = 100, segment.size = 0.1, show.legend = FALSE, force_pull = 0, nudge_x = 2.5, direction = "y", hjust = 0) +
  xlim(-5, 5) +
  theme_cowplot() +
  theme(text = element_text(size=14), 
  axis.text.x = element_text(angle=90, hjust=1, vjust=0.5),
  legend.text = element_text(size = 10),
  legend.title = element_text(size = 10),
  legend.position = "right") +
  xlab("log2FC (Never smokers exposed\nto PM2.5 vs Filtered Air)") + ylab("log2FC (Mice exposed to\nPM2.5 vs Control)")
